<?php
/**
 * Plugin Name: YouTube Playlist Plugin (EasyToolsWP)
 * Description: Display a YouTube playlist with the first video playing and the rest as thumbnails. [etwp-youtube-video playlist="YOUR_PLAYLIST_ID" items="10" video_height="315" show_video_title="true" show_thumbnail_title="true"]
 * Version: 1.2
 * Author: EasyToolsWP
 * Author URI: https://www.easytoolswp.com
 */

// Hook for adding admin menus
add_action('admin_menu', 'youtube_playlist_plugin_menu');

// Action function for the above hook
function youtube_playlist_plugin_menu() {
    add_submenu_page(
        '',
        'YouTube Playlist Plugin Settings', 
        'YouTube Playlist', 
        'manage_options', 
        'easytoolswp_pro-settings', 
        'youtube_playlist_plugin_options'
    );
}

// Display the admin options page
function youtube_playlist_plugin_options() {
    ?>
    <div class="wrap">
        <form method="post" action="options.php">
            <?php
            settings_fields('youtube_playlist_plugin_options');
            do_settings_sections('youtube-playlist-plugin');
            submit_button();
            ?>
        </form>
		
		<div>
			<p>
				Find your Youtube API key<br/>
				<a href="https://console.cloud.google.com" target="_blank">https://console.cloud.google.com</a>
			</p>
		<p>
			Shortcode:<br/>
			[etwp-youtube-video playlist="YOUR_PLAYLIST_ID" items="10" video_height="315" show_video_title="true" show_thumbnail_title="true"]</p>
			</div>
    </div>
    <?php
}

// Register and define the settings
add_action('admin_init', 'youtube_playlist_plugin_admin_init');

function youtube_playlist_plugin_admin_init(){
    register_setting(
        'youtube_playlist_plugin_options',
        'youtube_playlist_plugin_options',
        'youtube_playlist_plugin_options_validate'
    );

    add_settings_section(
        'youtube_playlist_plugin_main',
        'Youtube Automatic Playlist',
        'youtube_playlist_plugin_section_text',
        'youtube-playlist-plugin'
    );

    add_settings_field(
        'youtube_playlist_plugin_api_key',
        'YouTube API Key',
        'youtube_playlist_plugin_setting_api_key',
        'youtube-playlist-plugin',
        'youtube_playlist_plugin_main'
    );
}

function youtube_playlist_plugin_section_text() {
    echo '<p>Enter your YouTube API Key below:</p>';
}

function youtube_playlist_plugin_setting_api_key() {
    $options = get_option('youtube_playlist_plugin_options');
    echo "<input id='youtube_playlist_plugin_api_key' name='youtube_playlist_plugin_options[api_key]' size='40' type='text' value='{$options['api_key']}' />";
}

function youtube_playlist_plugin_options_validate($input) {
    $newinput['api_key'] = trim($input['api_key']);
    return $newinput;
}

// Shortcode for displaying the YouTube playlist
function youtube_playlist_shortcode($atts) {
    $options = get_option('youtube_playlist_plugin_options');
    $api_key = $options['api_key'];

    if (empty($api_key)) {
        return "API Key is required. Please enter it in the settings.";
    }

    $atts = shortcode_atts(
        array(
            'playlist' => '',
            'items' => 1,
            'video_height' => 315,
            'show_video_title' => false,
            'show_thumbnail_title' => false,
        ), $atts, 'etwp-youtube-video');

    if (empty($atts['playlist'])) {
        return "Playlist ID is required.";
    }

    $api_url = "https://www.googleapis.com/youtube/v3/playlistItems?part=snippet&maxResults={$atts['items']}&playlistId={$atts['playlist']}&key={$api_key}";

    // Fetch data from YouTube API
    $response = wp_remote_get($api_url);

    if (is_wp_error($response)) {
        return "Unable to retrieve videos.";
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (empty($data['items'])) {
        return "No videos found.";
    }

    $output = '<div class="youtube-playlist">';
    $first_video = true;

    foreach ($data['items'] as $item) {
        $video_id = $item['snippet']['resourceId']['videoId'];
        $title = $item['snippet']['title'];
        $thumbnail = $item['snippet']['thumbnails']['medium']['url'];

        if ($first_video) {
            $output .= "<div class='youtube-video'><iframe width='100%' height='{$atts['video_height']}' src='https://www.youtube.com/embed/{$video_id}' frameborder='0' allow='accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture' allowfullscreen></iframe>";
            if ($atts['show_video_title']) {
                $output .= "<p>{$title}</p>";
            }
            $output .= "</div>";
            $first_video = false;
        } else {
            $output .= "<div class='youtube-thumbnail'>";
            $output .= "<a href='#' class='thumbnail-link' data-video-id='{$video_id}' data-video-title='{$title}'>";
            $output .= "<img src='{$thumbnail}' alt='{$title}' />";
            if ($atts['show_thumbnail_title']) {
                $output .= "<p>{$title}</p>";
            }
            $output .= "</a>";
            $output .= "</div>";
        }
    }

    $output .= '</div>';

    // Enqueue JavaScript for thumbnail click handler and scroll to top
    $output .= '<script>
                    jQuery(document).ready(function($) {
                        $(".thumbnail-link").click(function(e) {
                            e.preventDefault();
                            var videoId = $(this).data("video-id");
                            var videoTitle = $(this).data("video-title");
                            var embedUrl = "https://www.youtube.com/embed/" + videoId;
                            $(".youtube-video iframe").attr("src", embedUrl);
                            $(".youtube-video p").text(videoTitle);
                            $("html, body").animate({ scrollTop: $(".youtube-video").offset().top }, 1000);
                        });
                    });
                </script>';

    return $output;
}

add_shortcode('etwp-youtube-video', 'youtube_playlist_shortcode');

// Enqueue plugin styles
function youtube_playlist_plugin_styles() {
    wp_enqueue_style('youtube-playlist-plugin-styles', plugins_url('etwp-youtube-playlist-plugin.css', __FILE__));
}

add_action('wp_enqueue_scripts', 'youtube_playlist_plugin_styles');


// Check if EasyTools-v2 plugin is active
function check_easytools_plugin() {
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');

    if (!is_plugin_active('easytoolswp-v2/easytoolswp-v2.php')) {
        add_action('admin_notices', 'easytools_missing_notice');
    }
}

// Display notice if EasyTools-v2 plugin is missing
function easytools_missing_notice() {
    ?>
    <div class="notice notice-warning is-dismissible">
        <p><?php _e('<strong>EasyToolsWP V2</strong> required for Youtube Playlist to work. Download <a href="https://www.easytoolswp.com" target="_blank">EasyToolsWP V2</a>.', 'your-text-domain'); ?></p>
    </div>
    <?php
}

// Hook into admin initialization to check for EasyTools-v2 plugin
add_action('admin_init', 'check_easytools_plugin');

